@@ -13,8 +13,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from __future__ import print_function
-
 import logging
 import os
 import sys
@@ -31,6 +29,7 @@ from aodhclient import noauth
 from aodhclient.v2 import alarm_cli
 from aodhclient.v2 import alarm_history_cli
 from aodhclient.v2 import capabilities_cli
+from aodhclient.v2 import metrics_cli
 
 
 class AodhCommandManager(commandmanager.CommandManager):
@@ -45,6 +44,7 @@ class AodhCommandManager(commandmanager.CommandManager):
         "alarm-history show": alarm_history_cli.CliAlarmHistoryShow,
         "alarm-history search": alarm_history_cli.CliAlarmHistorySearch,
         "capabilities list": capabilities_cli.CliCapabilitiesList,
+        "alarm metrics": metrics_cli.CliMetrics,
     }
 
     def load_commands(self, namespace):
@@ -54,12 +54,12 @@ class AodhCommandManager(commandmanager.CommandManager):
 
 class AodhShell(app.App):
     def __init__(self):
-        super(AodhShell, self).__init__(
+        super().__init__(
             description='Aodh command line client',
             version=__version__,
             command_manager=AodhCommandManager('aodhclient'),
             deferred_help=True,
-            )
+        )
 
         self._client = None
 
@@ -74,7 +74,7 @@ class AodhShell(app.App):
         :param version: version number for the application
         :paramtype version: str
         """
-        parser = super(AodhShell, self).build_option_parser(
+        parser = super().build_option_parser(
             description, version, argparse_kwargs={'allow_abbrev': False})
         # Global arguments, one day this should go to keystoneauth1
         parser.add_argument(
@@ -141,7 +141,7 @@ class AodhShell(app.App):
             # Set this here so cliff.app.configure_logging() can work
             self.options.verbose_level = 3
 
-        super(AodhShell, self).configure_logging()
+        super().configure_logging()
         root_logger = logging.getLogger('')
 
         # Set logging to the requested level
